==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/ChampDisciplVdiDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ChampDisciplVdiDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ChampDisciplVdiDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codChampDisciplinaire" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="poids" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ChampDisciplVdiDTO", namespace = "ChampDisciplVdiDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codChampDisciplinaire",
    "poids"
})
public class ChampDisciplVdiDTO {

    @XmlElement(required = true, nillable = true)
    protected String codChampDisciplinaire;
    @XmlElement(nillable = true)
    protected String poids;

    /**
     * Obtient la valeur de la propriété codChampDisciplinaire.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodChampDisciplinaire() {
        return codChampDisciplinaire;
    }

    /**
     * Définit la valeur de la propriété codChampDisciplinaire.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodChampDisciplinaire(String value) {
        this.codChampDisciplinaire = value;
    }

    /**
     * Obtient la valeur de la propriété poids.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPoids() {
        return poids;
    }

    /**
     * Définit la valeur de la propriété poids.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPoids(String value) {
        this.poids = value;
    }

}

==> apo-ws-client-6.00.51.1-sources.jar: fr/univlorraine/apowsclient/creationSE/ChampDisciplVdiDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ChampDisciplVdiDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ChampDisciplVdiDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codChampDisciplinaire" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="poids" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ChampDisciplVdiDTO", namespace = "ChampDisciplVdiDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codChampDisciplinaire",
    "poids"
})
public class ChampDisciplVdiDTO {

    @XmlElement(required = true, nillable = true)
    protected String codChampDisciplinaire;
    @XmlElement(required = true, nillable = true)
    protected String poids;

    /**
     * Obtient la valeur de la propriété codChampDisciplinaire.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodChampDisciplinaire() {
        return codChampDisciplinaire;
    }

    /**
     * Définit la valeur de la propriété codChampDisciplinaire.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodChampDisciplinaire(String value) {
        this.codChampDisciplinaire = value;
    }

    /**
     * Obtient la valeur de la propriété poids.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPoids() {
        return poids;
    }

    /**
     * Définit la valeur de la propriété poids.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPoids(String value) {
        this.poids = value;
    }

}
